@@ -25,12 +25,25 @@ else:
 
 __all__ = (
     "ASN1SubjectTypeDef",
+    "AccessDescriptionTypeDef",
+    "AccessMethodTypeDef",
     "CertificateAuthorityConfigurationTypeDef",
     "CertificateAuthorityTypeDef",
     "CrlConfigurationTypeDef",
+    "CsrExtensionsTypeDef",
+    "EdiPartyNameTypeDef",
+    "ExtendedKeyUsageTypeDef",
+    "ExtensionsTypeDef",
+    "GeneralNameTypeDef",
+    "KeyUsageTypeDef",
+    "OtherNameTypeDef",
     "PermissionTypeDef",
+    "PolicyInformationTypeDef",
+    "PolicyQualifierInfoTypeDef",
+    "QualifierTypeDef",
     "RevocationConfigurationTypeDef",
     "TagTypeDef",
+    "ApiPassthroughTypeDef",
     "CreateCertificateAuthorityAuditReportResponseTypeDef",
     "CreateCertificateAuthorityResponseTypeDef",
     "DescribeCertificateAuthorityAuditReportResponseTypeDef",
@@ -69,8 +82,24 @@ ASN1SubjectTypeDef = TypedDict(
     total=False,
 )
 
-CertificateAuthorityConfigurationTypeDef = TypedDict(
-    "CertificateAuthorityConfigurationTypeDef",
+AccessDescriptionTypeDef = TypedDict(
+    "AccessDescriptionTypeDef",
+    {"AccessMethod": "AccessMethodTypeDef", "AccessLocation": "GeneralNameTypeDef"},
+)
+
+AccessMethodTypeDef = TypedDict(
+    "AccessMethodTypeDef",
+    {
+        "CustomObjectIdentifier": str,
+        "AccessMethodType": Literal[
+            "CA_REPOSITORY", "RESOURCE_PKI_MANIFEST", "RESOURCE_PKI_NOTIFY"
+        ],
+    },
+    total=False,
+)
+
+_RequiredCertificateAuthorityConfigurationTypeDef = TypedDict(
+    "_RequiredCertificateAuthorityConfigurationTypeDef",
     {
         "KeyAlgorithm": Literal["RSA_2048", "RSA_4096", "EC_prime256v1", "EC_secp384r1"],
         "SigningAlgorithm": Literal[
@@ -84,6 +113,19 @@ CertificateAuthorityConfigurationTypeDef = TypedDict(
         "Subject": "ASN1SubjectTypeDef",
     },
 )
+_OptionalCertificateAuthorityConfigurationTypeDef = TypedDict(
+    "_OptionalCertificateAuthorityConfigurationTypeDef",
+    {"CsrExtensions": "CsrExtensionsTypeDef"},
+    total=False,
+)
+
+
+class CertificateAuthorityConfigurationTypeDef(
+    _RequiredCertificateAuthorityConfigurationTypeDef,
+    _OptionalCertificateAuthorityConfigurationTypeDef,
+):
+    pass
+
 
 CertificateAuthorityTypeDef = TypedDict(
     "CertificateAuthorityTypeDef",
@@ -119,6 +161,85 @@ class CrlConfigurationTypeDef(_RequiredCrlConfigurationTypeDef, _OptionalCrlConf
     pass
 
 
+CsrExtensionsTypeDef = TypedDict(
+    "CsrExtensionsTypeDef",
+    {"KeyUsage": "KeyUsageTypeDef", "SubjectInformationAccess": List["AccessDescriptionTypeDef"]},
+    total=False,
+)
+
+_RequiredEdiPartyNameTypeDef = TypedDict("_RequiredEdiPartyNameTypeDef", {"PartyName": str})
+_OptionalEdiPartyNameTypeDef = TypedDict(
+    "_OptionalEdiPartyNameTypeDef", {"NameAssigner": str}, total=False
+)
+
+
+class EdiPartyNameTypeDef(_RequiredEdiPartyNameTypeDef, _OptionalEdiPartyNameTypeDef):
+    pass
+
+
+ExtendedKeyUsageTypeDef = TypedDict(
+    "ExtendedKeyUsageTypeDef",
+    {
+        "ExtendedKeyUsageType": Literal[
+            "SERVER_AUTH",
+            "CLIENT_AUTH",
+            "CODE_SIGNING",
+            "EMAIL_PROTECTION",
+            "TIME_STAMPING",
+            "OCSP_SIGNING",
+            "SMART_CARD_LOGIN",
+            "DOCUMENT_SIGNING",
+            "CERTIFICATE_TRANSPARENCY",
+        ],
+        "ExtendedKeyUsageObjectIdentifier": str,
+    },
+    total=False,
+)
+
+ExtensionsTypeDef = TypedDict(
+    "ExtensionsTypeDef",
+    {
+        "CertificatePolicies": List["PolicyInformationTypeDef"],
+        "ExtendedKeyUsage": List["ExtendedKeyUsageTypeDef"],
+        "KeyUsage": "KeyUsageTypeDef",
+        "SubjectAlternativeNames": List["GeneralNameTypeDef"],
+    },
+    total=False,
+)
+
+GeneralNameTypeDef = TypedDict(
+    "GeneralNameTypeDef",
+    {
+        "OtherName": "OtherNameTypeDef",
+        "Rfc822Name": str,
+        "DnsName": str,
+        "DirectoryName": "ASN1SubjectTypeDef",
+        "EdiPartyName": "EdiPartyNameTypeDef",
+        "UniformResourceIdentifier": str,
+        "IpAddress": str,
+        "RegisteredId": str,
+    },
+    total=False,
+)
+
+KeyUsageTypeDef = TypedDict(
+    "KeyUsageTypeDef",
+    {
+        "DigitalSignature": bool,
+        "NonRepudiation": bool,
+        "KeyEncipherment": bool,
+        "DataEncipherment": bool,
+        "KeyAgreement": bool,
+        "KeyCertSign": bool,
+        "CRLSign": bool,
+        "EncipherOnly": bool,
+        "DecipherOnly": bool,
+    },
+    total=False,
+)
+
+OtherNameTypeDef = TypedDict("OtherNameTypeDef", {"TypeId": str, "Value": str})
+
 PermissionTypeDef = TypedDict(
     "PermissionTypeDef",
     {
@@ -132,6 +253,29 @@ PermissionTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredPolicyInformationTypeDef = TypedDict(
+    "_RequiredPolicyInformationTypeDef", {"CertPolicyId": str}
+)
+_OptionalPolicyInformationTypeDef = TypedDict(
+    "_OptionalPolicyInformationTypeDef",
+    {"PolicyQualifiers": List["PolicyQualifierInfoTypeDef"]},
+    total=False,
+)
+
+
+class PolicyInformationTypeDef(
+    _RequiredPolicyInformationTypeDef, _OptionalPolicyInformationTypeDef
+):
+    pass
+
+
+PolicyQualifierInfoTypeDef = TypedDict(
+    "PolicyQualifierInfoTypeDef",
+    {"PolicyQualifierId": Literal["CPS"], "Qualifier": "QualifierTypeDef"},
+)
+
+QualifierTypeDef = TypedDict("QualifierTypeDef", {"CpsUri": str})
+
 RevocationConfigurationTypeDef = TypedDict(
     "RevocationConfigurationTypeDef", {"CrlConfiguration": "CrlConfigurationTypeDef"}, total=False
 )
@@ -144,6 +288,12 @@ class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
+ApiPassthroughTypeDef = TypedDict(
+    "ApiPassthroughTypeDef",
+    {"Extensions": "ExtensionsTypeDef", "Subject": "ASN1SubjectTypeDef"},
+    total=False,
+)
+
 CreateCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
     "CreateCertificateAuthorityAuditReportResponseTypeDef",
     {"AuditReportId": str, "S3Key": str},
